==> haskell-hls-module-name-plugin-2.0.0.1-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.0.0.1
visibility:           public
id:                   hls-module-name-plugin-2.0.0.1-9E1WuHrgTgJJ4tCdPFFoZz
key:                  hls-module-name-plugin-2.0.0.1-9E1WuHrgTgJJ4tCdPFFoZz
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  c95ead49601438c057a76b916961ed51
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.0.0.1-9E1WuHrgTgJJ4tCdPFFoZz
depends:
    aeson-2.1.2.1-HdmwuFbnNgF6PqutsUaf6Y base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.0.0.1-CYzfpYBpuZ75dIm7DeRo3p
    hls-plugin-api-2.0.0.1-Q4NDRaykp39YbFmnmr4V8
    lsp-1.6.0.0-163IfZYucxl8mmyXdodCcB text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-DaOkK38PYRa9pF7ZwbG4ZB

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-module-name-plugin-2.0.0.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-module-name-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-module-name-plugin
version:              2.0.0.1
visibility:           public
id:                   hls-module-name-plugin-2.0.0.1-AaDTBdGXbMqJROcoE7SjTS
key:                  hls-module-name-plugin-2.0.0.1-AaDTBdGXbMqJROcoE7SjTS
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Module name plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  f95f9d229a75d0d170ffbf09608c1e98
exposed:              True
exposed-modules:      Ide.Plugin.ModuleName
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.1

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.1

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-module-name-plugin-2.0.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-module-name-plugin
hs-libraries:         HShls-module-name-plugin-2.0.0.1-AaDTBdGXbMqJROcoE7SjTS
depends:
    aeson-2.1.2.1-4cRYi3WcVwTKRqMhXUztfB base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    ghcide-2.0.0.1-2VdAESyZlyZ7W6WbsIAIPv
    hls-plugin-api-2.0.0.1-JjerfMkgU07E2M0jrTsSiW
    lsp-1.6.0.0-GX9aS0g7WYQKTWHFcgLnkB text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-A2tjqfQXDXnFd3Ae9FP0C3

haddock-interfaces:
    /usr/share/doc/haskell-hls-module-name-plugin/html/hls-module-name-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-module-name-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
